@@ -1,6 +1,9 @@
 import os
+import json
 from urllib.parse import urljoin
+from base64 import urlsafe_b64decode
 import requests
+from flask import request
 
 GCP_PROJECT = os.environ["GCP_PROJECT"]
 FUNCTION_REGION = os.environ["FUNCTION_REGION"]
@@ -42,3 +45,10 @@ def call(name, data):
             "status_code": None,
             "content": {"message": str(e)},
         }
+
+
+def user_info():
+    encoded_user_info = request.headers.get("X-Endpoint-API-UserInfo")
+    if encoded_user_info:
+        return json.loads(urlsafe_b64decode(encoded_user_info))
+    return None
